/*---------------------------------------------------------------------------*\
 =========                   |
 \\      /   F ield          | OpenFOAM: The Open Source CFD Toolbox
  \\    /    O peration      |
   \\  /     A nd            | Copyright (C) 1991-2005 OpenCFD Ltd.
    \\/      M anipulation   |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
    Free Software Foundation; either version 2 of the License, or (at your
    option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM; if not, write to the Free Software Foundation,
    Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

Application
    calcPressureDifference

Description
    calculates the Pressure Difference between two patches (average pressure at the patches)

\*---------------------------------------------------------------------------*/

#include "fvCFD.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
// Main program:

int main(int argc, char *argv[])
{
#   include "addTimeOptions.H"

#   include "setRootCase.H"
#   include "createTime.H"
#   include "createMesh.H"

    // Read control dictionary
    IOdictionary calcPressureDifferenceDict
    (
        IOobject
        (
            "calcPressureDifferenceDict",
            runTime.system(),
            mesh,
            IOobject::MUST_READ,
            IOobject::NO_WRITE
        )
    );

    const word inletName =calcPressureDifferenceDict.lookup("inlet");
    const word outletName=calcPressureDifferenceDict.lookup("outlet");

    dimensionedScalar rho=dimensionedScalar("noRho",dimensionSet(0,0,0,0,0,0,0),1);

    if(calcPressureDifferenceDict.found("rho")) {

      dimensionedScalar tmp=calcPressureDifferenceDict.lookup("rho");
      rho.value()=tmp.value();
      rho.dimensions().reset(tmp.dimensions());

      Info << "Reseting rho to " << rho << " (Assuming incompressible case)\n" << endl;
    }

    label inletIndex=mesh.boundaryMesh().findPatchID(inletName);
    if(inletIndex<0) {
            FatalErrorIn(args.executable())
              << "No patch " << inletName << " in mesh"
              << exit(FatalError);
     }
    label outletIndex=mesh.boundaryMesh().findPatchID(outletName);
    if(outletIndex<0) {
            FatalErrorIn(args.executable())
              << "No patch " << outletName << " in mesh"
              << exit(FatalError);
     }

    // Get times list
    instantList Times = runTime.times();

    // set startTime and endTime depending on -time and -latestTime options
#   include "checkTimeOptions.H"

    for (label i=startTime; i<endTime; i++)
    {
        runTime.setTime(Times[i], i);

        Info<< "Time = " << runTime.timeName() << endl;

#       include "createP.H"
	
	dimensionedScalar inletPressure=dimensionedScalar("p",p.dimensions()
							  ,average(p.boundaryField()[inletIndex]));
	dimensionedScalar outletPressure=dimensionedScalar("p",p.dimensions()
							   ,average(p.boundaryField()[outletIndex]));

	dimensionedScalar scaledInletPressure=rho*inletPressure;
	scaledInletPressure.name()="";

	dimensionedScalar scaledOutletPressure=rho*outletPressure;
	scaledOutletPressure.name()="";

	Info << " Pressure"
	     << " at " << inletName << " = " << scaledInletPressure
	     << " at " << outletName << " = " << scaledOutletPressure
	     << " -> Difference = " << scaledInletPressure-scaledOutletPressure << "\n" 
	     << endl;
    }

    Info << "End\n" << endl;

    return 0;
}


// ************************************************************************* //
